#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant
version:              0.20.3.0
visibility:           public
id:                   servant-0.20.3.0-49tnCxMAnTq4pzH6t4ADzQ
key:                  servant-0.20.3.0-49tnCxMAnTq4pzH6t4ADzQ
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  015ad2d7c392955586f7fd235ed26f4a
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.Host
    Servant.API.HttpVersion Servant.API.IsSecure Servant.API.Modifiers
    Servant.API.MultiVerb Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Range
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.ServerSentEvents
    Servant.API.Status Servant.API.Stream Servant.API.Sub
    Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.TypeLevel.List Servant.API.UVerb
    Servant.API.UVerb.Union Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.Internal.Response
    Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.3.0-49tnCxMAnTq4pzH6t4ADzQ
depends:
    QuickCheck-2.15.0.1-KQOdD0ZF7G37LlS7pS23f7
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    attoparsec-0.14.4-HxFEqrzE4jlDGISwMuQFm7 base-4.18.2.1
    bifunctors-5.6.3-40xKQKgYXzc6u9JTwdJvAF bytestring-0.11.5.3
    case-insensitive-1.2.1.0-42CJmR7jfDI1QxR1AA3Hru
    constraints-0.14.4-u7c7UZfLfK1zXpeNTfpu containers-0.6.7
    deepseq-1.4.8.1 generics-sop-0.5.1.4-Jm3azQ1bHSLFwLmIcDOhGt
    http-api-data-0.6.1-C2eb7z78pO32HIC9pWDsJQ
    http-media-0.8.1.1-8f0O4gDGchR1Um751V2iJc
    http-types-0.12.4-1B8W97d7Bm7JkBvipzT6Xa
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-6IsL4l5xPlJ2SbjqeOZPL6
    singleton-bool-0.1.8-CLjT9B1MQbzAoJGVGw8Twi
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS text-2.0.2
    transformers-0.6.1.0 vault-0.3.1.6-Izfbd4ZXUHn5Egg8eCijcw

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

